pub struct MbmProgress {
pub current_migration: u32,
pub total_migrations: u32,
pub current_migration_steps: u32,
pub current_migration_max_steps: Option<u32>,
}Expand description
Progress information for the current migration.
Fields
current_migration: u32The index of the current migration.
total_migrations: u32The total number of migrations.
current_migration_steps: u32The number of steps that the current migration has taken.
current_migration_max_steps: Option<u32>The maximum number of steps that the current migration can take.
Can be None if the migration does not know or there is no limit.